Module applier

Module applier 

Transform applier — replaces pattern matches with the after_template.

The applier takes a source string, a Pattern, and a list of Matches and produces a new string where every match has been replaced according to the pattern’s after_template with variable bindings substituted.

Replacements are applied back-to-front (highest byte offset first) so that earlier byte ranges remain valid as we mutate the string.

Structs

TransformApplier
Applies pattern-based transformations to source code.